==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractDefinitionStmt.h <==
// public abstract class soot.jimple.internal.AbstractDefinitionStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_jimple_internal_AbstractDefinitionStmt_H_
#define _JC_soot_jimple_internal_AbstractDefinitionStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	_jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	_jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$refs	_jc_soot_jimple_internal_AbstractDefinitionStmt$refs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs	_jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object	_jc_soot_jimple_internal_AbstractDefinitionStmt$object;

typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtable	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractDefinitionStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_internal_AbstractDefinitionStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern jboolean _jc_soot_jimple_internal_AbstractDefinitionStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getDefBoxes$09ed871867d10b27(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getLeftOp$81175b6a6f9b0911(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getLeftOpBox$470be2d3736e4e15(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getRightOp$b163824a99afafb3(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getRightOpBox$8800ffb58c6ced84(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getDefBoxes$09ed871867d10b27;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getLeftOp$81175b6a6f9b0911;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getLeftOpBox$470be2d3736e4e15;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getRightOp$b163824a99afafb3;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getRightOpBox$8800ffb58c6ced84;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getUseBoxes$8c22fb3c6dc4d01e;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods {
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getDefBoxes$09ed871867d10b27)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getLeftOp$81175b6a6f9b0911)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getLeftOpBox$470be2d3736e4e15)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getRightOp$b163824a99afafb3)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getRightOpBox$8800ffb58c6ced84)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs {
	struct _jc_object	*leftBox;
	struct _jc_object	*rightBox;
	struct _jc_object	*defBoxes;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$refs {
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object {
	_jc_soot_jimple_internal_AbstractDefinitionStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype _jc_soot_jimple_internal_AbstractDefinitionStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractDefinitionStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractDefinitionStmt$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractDefinitionStmt_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractDefinitionStmt.h <==
// public abstract class soot.jimple.internal.AbstractDefinitionStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_jimple_internal_AbstractDefinitionStmt_H_
#define _JC_soot_jimple_internal_AbstractDefinitionStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	_jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	_jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$refs	_jc_soot_jimple_internal_AbstractDefinitionStmt$refs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs	_jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object	_jc_soot_jimple_internal_AbstractDefinitionStmt$object;

typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtable	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractDefinitionStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_internal_AbstractDefinitionStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_internal_AbstractDefinitionStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getDefBoxes$09ed871867d10b27(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getLeftOp$81175b6a6f9b0911(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getLeftOpBox$470be2d3736e4e15(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getRightOp$b163824a99afafb3(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getRightOpBox$8800ffb58c6ced84(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractDefinitionStmt$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getDefBoxes$09ed871867d10b27;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getLeftOp$81175b6a6f9b0911;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getLeftOpBox$470be2d3736e4e15;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getRightOp$b163824a99afafb3;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getRightOpBox$8800ffb58c6ced84;
extern _jc_method _jc_soot_jimple_internal_AbstractDefinitionStmt$method_info$getUseBoxes$8c22fb3c6dc4d01e;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods {
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDefBoxes$09ed871867d10b27)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLeftOp$81175b6a6f9b0911)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLeftOpBox$470be2d3736e4e15)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getRightOp$b163824a99afafb3)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getRightOpBox$8800ffb58c6ced84)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs {
	struct _jc_object	*leftBox;
	struct _jc_object	*rightBox;
	struct _jc_object	*defBoxes;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$refs {
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractDefinitionStmt$object {
	_jc_soot_jimple_internal_AbstractDefinitionStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractDefinitionStmt$vtype _jc_soot_jimple_internal_AbstractDefinitionStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractDefinitionStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractDefinitionStmt$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractDefinitionStmt_H_ */
